==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebFilteringExpressionsTreeDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebFilteringExpressionsTreeDetailDescription, _super);
    function WebFilteringExpressionsTreeDetailDescription() {
        var _this = _super.call(this) || this;
        _this.f = null;
        _this.k = null;
        _this.j = null;
        _this.l = null;
        return _this;
    }
    WebFilteringExpressionsTreeDetailDescription.prototype.get_type = function () {
        return "WebFilteringExpressionsTreeDetail";
    };
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "filteringOperands", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.e("FilteringOperands");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "operator", {
        get: function () {
            return this.k;
        },
        set: function (a) {
            this.k = a;
            this.e("Operator");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "fieldName", {
        get: function () {
            return this.j;
        },
        set: function (a) {
            this.j = a;
            this.e("FieldName");
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "treeType", {
        get: function () {
            return this.l;
        },
        set: function (a) {
            this.l = a;
            this.e("TreeType");
        },
        enumerable: true,
        configurable: true
    });
    WebFilteringExpressionsTreeDetailDescription.$t = markType(WebFilteringExpressionsTreeDetailDescription, 'WebFilteringExpressionsTreeDetailDescription', Description.$);
    WebFilteringExpressionsTreeDetailDescription.__marshalByValue = true;
    WebFilteringExpressionsTreeDetailDescription.__marshalByValueAlias = "FilteringExpressionsTreeDetail";
    return WebFilteringExpressionsTreeDetailDescription;
}(Description));
export { WebFilteringExpressionsTreeDetailDescription };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebFilteringExpressionsTreeDetailDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
var WebFilteringExpressionsTreeDetailDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFilteringExpressionsTreeDetailDescription, _super);
    function WebFilteringExpressionsTreeDetailDescription() {
        var _this = _super.call(this) || this;
        _this.h = null;
        _this.s = null;
        _this.m = null;
        _this.r = null;
        _this.q = null;
        _this.p = null;
        _this.i = null;
        return _this;
    }
    WebFilteringExpressionsTreeDetailDescription.prototype.get_type = function () {
        return "WebFilteringExpressionsTreeDetail";
    };
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "type", {
        get: function () {
            return this.get_type();
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "filteringOperands", {
        get: function () {
            return this.h;
        },
        set: function (a) {
            this.h = a;
            this.g("FilteringOperands");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "treeType", {
        get: function () {
            return this.s;
        },
        set: function (a) {
            this.s = a;
            this.g("TreeType");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "owner", {
        get: function () {
            return this.m;
        },
        set: function (a) {
            this.m = a;
            this.g("Owner");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "operator", {
        get: function () {
            return this.r;
        },
        set: function (a) {
            this.r = a;
            this.g("Operator");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "fieldName", {
        get: function () {
            return this.q;
        },
        set: function (a) {
            this.q = a;
            this.g("FieldName");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "entity", {
        get: function () {
            return this.p;
        },
        set: function (a) {
            this.p = a;
            this.g("Entity");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(WebFilteringExpressionsTreeDetailDescription.prototype, "returnFields", {
        get: function () {
            return this.i;
        },
        set: function (a) {
            this.i = a;
            this.g("ReturnFields");
        },
        enumerable: false,
        configurable: true
    });
    WebFilteringExpressionsTreeDetailDescription.$t = markType(WebFilteringExpressionsTreeDetailDescription, 'WebFilteringExpressionsTreeDetailDescription', Description.$);
    WebFilteringExpressionsTreeDetailDescription.__marshalByValue = true;
    WebFilteringExpressionsTreeDetailDescription.__marshalByValueAlias = "FilteringExpressionsTreeDetail";
    return WebFilteringExpressionsTreeDetailDescription;
}(Description));
export { WebFilteringExpressionsTreeDetailDescription };
